==> netw-ib-ox-ag_5.30.0.orig.tar.gz: netw-ib-ox-ag-5.30.0/src/netwib-bin_windows/include/netwib/def.h <==
/* do not change */
#define NETWIBDEF_SYSNAME "Windows"
#define NETWIBDEF_SYSNAME_Windows 1
#define NETWIBDEF_SYSARCH "i386"
#define NETWIBDEF_SYSARCH_i386 1
#define NETWIBDEF_ARCH_ENDIAN 0
#define NETWIBDEF_ARCH_BITS 32
#define NETWIBDEF_ARCH_ALIGN 0
#define NETWIBDEF_VERSION "5.30.0"
#define NETWIBDEF_VERSIONMAJOR 5
#define NETWIBDEF_VERSIONMINOR 30
#define NETWIBDEF_VERSIONMICRO 0
#define NETWIBDEF_LIBPTHREADINSTALLED 0
#define NETWIBDEF_LIBPTHREADFROMDCE 0
#define NETWIBDEF_LIBPTHREADFROMMIT 0
#define NETWIBDEF_LIBPCAPINSTALLED 1
#define NETWIBDEF_LIBPCAPFROMREDHAT 0
#define NETWIBDEF_LIBNETINSTALLED 0
#define NETWIBDEF_LIBNETVERSION11 0
#define NETWIBDEF_PROGCC ""
#define NETWIBDEF_PROGCCALIAS 0
#define NETWIBDEF_PROGCCWUNDEF 0
#define NETWIBDEF_PROGCCWSIGNC 0
#define NETWIBDEF_PROGAR ""
#define NETWIBDEF_PROGRANLIB ""
#define NETWIBDEF_PROGGREP ""
#define NETWIBDEF_INSTPREFIX ""
#define NETWIBDEF_INSTINCLUDE ""
#define NETWIBDEF_INSTLIB ""
#define NETWIBDEF_INSTBIN ""
#define NETWIBDEF_INSTMAN ""
#define NETWIBDEF_INSTMAN3 ""
#define NETWIBDEF_SUPPORT_SNIFF 1
#define NETWIBDEF_SUPPORT_SPOOF 1
#define NETWIBDEF_SUPPORT_ENCODETYPE_PCAP 1
#define NETWIBDEF_TYPE_INT8 char
#define NETWIBDEF_TYPE_UINT8 unsigned char
#define NETWIBDEF_TYPE_INT16 short
#define NETWIBDEF_TYPE_UINT16 unsigned short
#define NETWIBDEF_TYPE_INT32 int
#define NETWIBDEF_TYPE_UINT32 unsigned int
#define NETWIBDEF_TYPE_INT64 __int64
#define NETWIBDEF_TYPE_UINT64 unsigned __int64
#define NETWIBDEF_TYPE_INT64_FAKE 0
#define NETWIBDEF_HAVEINCL_PTHREAD 0
#define NETWIBDEF_HAVEINCL_STROPTS 0
#define NETWIBDEF_HAVEINCL_SCHED 0
#define NETWIBDEF_HAVEINCL_SYS_POLL 0
#define NETWIBDEF_HAVEINCL_SYS_PARAM 0
#define NETWIBDEF_HAVEINCL_SYS_SYSCTL 0
#define NETWIBDEF_HAVEINCL_SYS_IOCTL 0
#define NETWIBDEF_HAVEINCL_SYS_SOCKIO 0
#define NETWIBDEF_HAVEINCL_SYS_DLPI 0
#define NETWIBDEF_HAVEINCL_SYS_BUFMOD 0
#define NETWIBDEF_HAVEINCL_SYS_MMAN 0
#define NETWIBDEF_HAVEINCL_NET_ETHERNET 0
#define NETWIBDEF_HAVEINCL_NET_IF_ARP 0
#define NETWIBDEF_HAVEINCL_NET_IF_TYPES 0
#define NETWIBDEF_HAVEINCL_NET_IF_DL 0
#define NETWIBDEF_HAVEINCL_NET_BPF 0
#define NETWIBDEF_HAVEINCL_NETINET_IF_ETHER 0
#define NETWIBDEF_HAVEINCL_NETINET_ETHER 0
#define NETWIBDEF_HAVEINCL_NETPACKET_PACKET 0
#define NETWIBDEF_HAVEINCL_ASM_PAGE 0
#define NETWIBDEF_HAVEINCL_MACHINE_PARAM 0
#define NETWIBDEF_HAVETYPE_SIZE_T 0
#define NETWIBDEF_HAVETYPE_SOCKLEN_T 0
#define NETWIBDEF_HAVETYPE_SIGHANDLER_T 0
#define NETWIBDEF_HAVETYPE_SIG_T 0
#define NETWIBDEF_HAVETYPE_OFF_T 0
#define NETWIBDEF_HAVETYPE_PTHREAD_RWLOCK_T 0
#define NETWIBDEF_HAVETYPE_SOCKADDR_IN6 1
#define NETWIBDEF_HAVEFUNC_ETHER_NTOHOST 0
#define NETWIBDEF_HAVEFUNC_ETHER_HOSTTON 0
#define NETWIBDEF_HAVEFUNC_HSTRERROR 0
#define NETWIBDEF_HAVEFUNC_SNPRINTF 1
#define NETWIBDEF_HAVEFUNC_PCAP_FREECODE 1
#define NETWIBDEF_HAVEFUNC_PCAP_FREECODE2 0
#define NETWIBDEF_HAVEFUNC_PCAP_OPENDEAD 1
#define NETWIBDEF_HAVEFUNC_POLL 0
#define NETWIBDEF_HAVEFUNC_PATHCONF 0
#define NETWIBDEF_HAVEFUNC_SYSCONF 0
#define NETWIBDEF_HAVEFUNC_GETPAGESIZE 0
#define NETWIBDEF_HAVEFUNC_GETRLIMIT 0
#define NETWIBDEF_HAVEFUNC_NANOSLEEP 0
#define NETWIBDEF_HAVEFUNC_USLEEP 0
#define NETWIBDEF_HAVEFUNC_GETTIMEOFDAY 0
#define NETWIBDEF_HAVEFUNC_CLOCK_GETTIME 0
#define NETWIBDEF_HAVEFUNC_PTHREAD_MUTEX_TIMEDLOCK 0
#define NETWIBDEF_HAVEFUNC_PTHREAD_RWLOCK_TIMEDRDLOCK 0
#define NETWIBDEF_HAVEFUNC_PTHREAD_RWLOCK_TIMEDWRLOCK 0
#define NETWIBDEF_HAVEFUNC_PTHREAD_YIELD 0
#define NETWIBDEF_HAVEFUNC_SCHED_YIELD 0
#define NETWIBDEF_HAVEFUNC_GETPWNAM_R 0
#define NETWIBDEF_HAVEFUNC_GETGRNAM_R 0
#define NETWIBDEF_HAVEFUNC_GETGRGID_R 0
#define NETWIBDEF_HAVEFUNC_READDIR_R 0
#define NETWIBDEF_HAVEFUNC_GETHOSTBYNAME_R 0
#define NETWIBDEF_HAVEFUNC_GETHOSTBYADDR_R 0
#define NETWIBDEF_HAVEFUNC_GETNAMEINFO 0
#define NETWIBDEF_HAVEFUNC_GETADDRINFO 0
#define NETWIBDEF_HAVEFUNC_GETIPNODEBYNAME 0
#define NETWIBDEF_HAVEFUNC_GETIPNODEBYADDR 0
#define NETWIBDEF_HAVEFUNC_LOCALTIME_R 0
#define NETWIBDEF_HAVEVAR_HERRNO 1
#define NETWIBDEF_HAVEVAR_PATH_MAX 0
#define NETWIBDEF_HAVEVAR_NAME_MAX 0
#define NETWIBDEF_HAVEVAR_PAGE_SIZE 0
#define NETWIBDEF_HAVEVAR_PAGESIZE 0
#define NETWIBDEF_HAVEVAR_BIOCSHDRCMPLT 0
#define NETWIBDEF_HAVEVAR_SIOCGLIFCONF 0
#define NETWIBDEF_HAVEVAR_AF_INET6 1
#define NETWIBDEF_HAVEVAR_SC_GETPW_R_SIZE_MAX 0
#define NETWIBDEF_HAVEVAR_SC_GETGR_R_SIZE_MAX 0
#define NETWIBDEF_HAVEVAR_TM_GMTOFF 0

==> netw-ib-ox-ag_5.33.0.orig.tar.gz: netw-ib-ox-ag-5.33.0/src/netwib-bin_windows/include/netwib/def.h <==
/* do not change */
#define NETWIBDEF_SYSNAME "Windows"
#define NETWIBDEF_SYSNAME_Windows 1
#define NETWIBDEF_SYSARCH "i386"
#define NETWIBDEF_SYSARCH_i386 1
#define NETWIBDEF_ARCH_ENDIAN 0
#define NETWIBDEF_ARCH_BITS 32
#define NETWIBDEF_ARCH_ALIGN 0
#define NETWIBDEF_VERSION "5.33.0"
#define NETWIBDEF_VERSIONMAJOR 5
#define NETWIBDEF_VERSIONMINOR 33
#define NETWIBDEF_VERSIONMICRO 0
#define NETWIBDEF_LIBPTHREADINSTALLED 0
#define NETWIBDEF_LIBPTHREADFROMDCE 0
#define NETWIBDEF_LIBPTHREADFROMMIT 0
#define NETWIBDEF_LIBPCAPINSTALLED 1
#define NETWIBDEF_LIBPCAPFROMREDHAT 0
#define NETWIBDEF_LIBNETINSTALLED 0
#define NETWIBDEF_LIBNETVERSION11 0
#define NETWIBDEF_PROGCC ""
#define NETWIBDEF_PROGCCALIAS 0
#define NETWIBDEF_PROGCCWUNDEF 0
#define NETWIBDEF_PROGCCWSIGNC 0
#define NETWIBDEF_PROGAR ""
#define NETWIBDEF_PROGRANLIB ""
#define NETWIBDEF_PROGGREP ""
#define NETWIBDEF_INSTPREFIX ""
#define NETWIBDEF_INSTINCLUDE ""
#define NETWIBDEF_INSTLIB ""
#define NETWIBDEF_INSTBIN ""
#define NETWIBDEF_INSTMAN ""
#define NETWIBDEF_INSTMAN3 ""
#define NETWIBDEF_SUPPORT_SNIFF 1
#define NETWIBDEF_SUPPORT_SPOOF 1
#define NETWIBDEF_SUPPORT_ENCODETYPE_PCAP 1
#define NETWIBDEF_TYPE_INT8 char
#define NETWIBDEF_TYPE_UINT8 unsigned char
#define NETWIBDEF_TYPE_INT16 short
#define NETWIBDEF_TYPE_UINT16 unsigned short
#define NETWIBDEF_TYPE_INT32 int
#define NETWIBDEF_TYPE_UINT32 unsigned int
#define NETWIBDEF_TYPE_INT64 __int64
#define NETWIBDEF_TYPE_UINT64 unsigned __int64
#define NETWIBDEF_TYPE_INT64_FAKE 0
#define NETWIBDEF_HAVEINCL_PTHREAD 0
#define NETWIBDEF_HAVEINCL_STROPTS 0
#define NETWIBDEF_HAVEINCL_SCHED 0
#define NETWIBDEF_HAVEINCL_SYS_POLL 0
#define NETWIBDEF_HAVEINCL_SYS_PARAM 0
#define NETWIBDEF_HAVEINCL_SYS_SYSCTL 0
#define NETWIBDEF_HAVEINCL_SYS_IOCTL 0
#define NETWIBDEF_HAVEINCL_SYS_SOCKIO 0
#define NETWIBDEF_HAVEINCL_SYS_DLPI 0
#define NETWIBDEF_HAVEINCL_SYS_BUFMOD 0
#define NETWIBDEF_HAVEINCL_SYS_MMAN 0
#define NETWIBDEF_HAVEINCL_NET_ETHERNET 0
#define NETWIBDEF_HAVEINCL_NET_IF_ARP 0
#define NETWIBDEF_HAVEINCL_NET_IF_TYPES 0
#define NETWIBDEF_HAVEINCL_NET_IF_DL 0
#define NETWIBDEF_HAVEINCL_NET_BPF 0
#define NETWIBDEF_HAVEINCL_NETINET_IF_ETHER 0
#define NETWIBDEF_HAVEINCL_NETINET_ETHER 0
#define NETWIBDEF_HAVEINCL_NETPACKET_PACKET 0
#define NETWIBDEF_HAVEINCL_ASM_PAGE 0
#define NETWIBDEF_HAVEINCL_MACHINE_PARAM 0
#define NETWIBDEF_HAVETYPE_SIZE_T 0
#define NETWIBDEF_HAVETYPE_SOCKLEN_T 0
#define NETWIBDEF_HAVETYPE_SIGHANDLER_T 0
#define NETWIBDEF_HAVETYPE_SIG_T 0
#define NETWIBDEF_HAVETYPE_OFF_T 0
#define NETWIBDEF_HAVETYPE_PTHREAD_RWLOCK_T 0
#define NETWIBDEF_HAVETYPE_SOCKADDR_IN6 1
#define NETWIBDEF_HAVEFUNC_ETHER_NTOHOST 0
#define NETWIBDEF_HAVEFUNC_ETHER_HOSTTON 0
#define NETWIBDEF_HAVEFUNC_HSTRERROR 0
#define NETWIBDEF_HAVEFUNC_SNPRINTF 1
#define NETWIBDEF_HAVEFUNC_PCAP_FREECODE 1
#define NETWIBDEF_HAVEFUNC_PCAP_FREECODE2 0
#define NETWIBDEF_HAVEFUNC_PCAP_OPENDEAD 1
#define NETWIBDEF_HAVEFUNC_POLL 0
#define NETWIBDEF_HAVEFUNC_DIRFD 0
#define NETWIBDEF_HAVEFUNC_FPATHCONF 0
#define NETWIBDEF_HAVEFUNC_PATHCONF 0
#define NETWIBDEF_HAVEFUNC_SYSCONF 0
#define NETWIBDEF_HAVEFUNC_GETPAGESIZE 0
#define NETWIBDEF_HAVEFUNC_GETRLIMIT 0
#define NETWIBDEF_HAVEFUNC_NANOSLEEP 0
#define NETWIBDEF_HAVEFUNC_USLEEP 0
#define NETWIBDEF_HAVEFUNC_GETTIMEOFDAY 0
#define NETWIBDEF_HAVEFUNC_CLOCK_GETTIME 0
#define NETWIBDEF_HAVEFUNC_PTHREAD_MUTEX_TIMEDLOCK 0
#define NETWIBDEF_HAVEFUNC_PTHREAD_RWLOCK_TIMEDRDLOCK 0
#define NETWIBDEF_HAVEFUNC_PTHREAD_RWLOCK_TIMEDWRLOCK 0
#define NETWIBDEF_HAVEFUNC_PTHREAD_YIELD 0
#define NETWIBDEF_HAVEFUNC_SCHED_YIELD 0
#define NETWIBDEF_HAVEFUNC_GETPWNAM_R 0
#define NETWIBDEF_HAVEFUNC_GETGRNAM_R 0
#define NETWIBDEF_HAVEFUNC_GETGRGID_R 0
#define NETWIBDEF_HAVEFUNC_READDIR_R 0
#define NETWIBDEF_HAVEFUNC_GETHOSTBYNAME_R 0
#define NETWIBDEF_HAVEFUNC_GETHOSTBYADDR_R 0
#define NETWIBDEF_HAVEFUNC_GETNAMEINFO 0
#define NETWIBDEF_HAVEFUNC_GETADDRINFO 0
#define NETWIBDEF_HAVEFUNC_GETIPNODEBYNAME 0
#define NETWIBDEF_HAVEFUNC_GETIPNODEBYADDR 0
#define NETWIBDEF_HAVEFUNC_LOCALTIME_R 0
#define NETWIBDEF_HAVEVAR_HERRNO 1
#define NETWIBDEF_HAVEVAR_PATH_MAX 0
#define NETWIBDEF_HAVEVAR_NAME_MAX 0
#define NETWIBDEF_HAVEVAR_PAGE_SIZE 0
#define NETWIBDEF_HAVEVAR_PAGESIZE 0
#define NETWIBDEF_HAVEVAR_BIOCSHDRCMPLT 0
#define NETWIBDEF_HAVEVAR_SIOCGLIFCONF 0
#define NETWIBDEF_HAVEVAR_AF_INET6 1
#define NETWIBDEF_HAVEVAR_SC_GETPW_R_SIZE_MAX 0
#define NETWIBDEF_HAVEVAR_SC_GETGR_R_SIZE_MAX 0
#define NETWIBDEF_HAVEVAR_TM_GMTOFF 0
